==> seedsui-react-5.5.1.tgz: package/es/Body/Body.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
var _excluded = ["onTopRefresh", "onBottomRefresh", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect, useContext } from 'react';
import Instance from './instance.js';
import locale from './../locale';
import Container from './../Container';
import TopContainer from './TopContainer'; // 下拉刷新容器

var Body = forwardRef(function (_ref, ref) {
  var onTopRefresh = _ref.onTopRefresh,
      onBottomRefresh = _ref.onBottomRefresh,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var rootRef = useRef(null);
  var instance = useRef(null);
  var topContainerRef = useRef(null);
  var bottomContainerRef = useRef(null); // 节点

  useImperativeHandle(ref, function () {
    return {
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInstance: function getInstance() {
        return instance.current;
      }
    };
  }); // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    // 头部刷新,加载第一页
    if (onTopRefresh) {
      instance.current.params.onTopRefresh = onTopRefresh;
    } // 底部刷新,加载下一页


    if (onBottomRefresh) {
      instance.current.params.onBottomRefresh = onBottomRefresh;
    }
  } // 初始化


  useEffect(function () {
    if (typeof onTopRefresh === 'function' || typeof onBottomRefresh === 'function') {
      initInstance();
    }
  }, [onTopRefresh, onBottomRefresh]); // eslint-disable-line

  function initInstance() {
    return _initInstance.apply(this, arguments);
  }

  function _initInstance() {
    _initInstance = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              if (!instance.current) {
                _context.next = 2;
                break;
              }

              return _context.abrupt("return");

            case 2:
              instance.current = new Instance({
                // threshold: 100,
                // end: 200, // 头部下拉的结束位置
                // endRefresh: null, // 滑动到指位置后自动刷新
                // moveTimeout: 0, // 滑动超时, 解决ios手指滑动到原生tabbar上, 不触发onTouchEnd
                container: rootRef.current,
                onScroll: others.onScroll ? others.onScroll : null,
                onTopRefresh: onTopRefresh,
                // 头部刷新,加载第一页
                onBottomRefresh: onBottomRefresh,
                // 底部刷新,加载下一页
                // 构建实体
                topContainer: onTopRefresh ? topContainerRef.current : null,
                bottomContainer: onBottomRefresh ? bottomContainerRef.current : null,
                // 实体交互
                duration: 150,
                onPull: function onPull(e) {
                  var topContainer = e.topContainer;
                  topContainer.style.height = e.touches.currentPosY + 'px';
                  var topIcon = topContainer.querySelector('.body-pull-push-icon');
                  var topCaption = topContainer.querySelector('.body-pull-push-caption');

                  if (!e.isLoading) {
                    if (e.touches.currentPosY >= e.params.threshold) {
                      if (topIcon) topIcon.classList.add('body-pull-push-icon-down');
                      if (topCaption) topCaption.innerHTML = locale('释放立即刷新', 'release');
                    } else {
                      if (topIcon) topIcon.classList.remove('body-pull-push-icon-down');
                      if (topCaption) topCaption.innerHTML = locale('下拉可以刷新', 'pull_down');
                    }
                  }
                },
                onShowTop: function onShowTop(e) {
                  var topContainer = e.topContainer;
                  var topIcon = topContainer.querySelector('.body-pull-push-icon');
                  var topCaption = topContainer.querySelector('.body-pull-push-caption');
                  topContainer.style.height = e.params.threshold + 'px';
                  if (topIcon) topIcon.classList.remove('body-pull-push-icon-down');
                  if (topIcon) topIcon.classList.add('body-pull-push-icon-loading');
                  if (topCaption) topCaption.innerHTML = locale('正在刷新...', 'refreshing');
                },
                onHideTop: function onHideTop(e) {
                  var topContainer = e.topContainer;
                  topContainer.style.height = '0';
                },
                onTopHid: function onTopHid(e) {
                  var topContainer = e.topContainer;
                  var topIcon = topContainer.querySelector('.body-pull-push-icon');
                  if (topIcon) topIcon.classList.remove('body-pull-push-icon-down');
                  if (topIcon) topIcon.classList.remove('body-pull-push-icon-loading');
                }
              });

            case 3:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));
    return _initInstance.apply(this, arguments);
  }

  return /*#__PURE__*/React.createElement("article", _extends({
    ref: rootRef
  }, others, {
    className: "body" + (others.className ? ' ' + others.className : '')
  }), /*#__PURE__*/React.createElement(TopContainer, {
    ref: topContainerRef
  }), children);
});
export default Body;

==> seedsui-react-5.5.5.tgz: package/es/Body/Body.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
var _excluded = ["onTopRefresh", "onBottomRefresh", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import Instance from './instance.js';
import locale from './../locale';
import TopContainer from './TopContainer'; // 下拉刷新容器

var Body = forwardRef(function (_ref, ref) {
  var onTopRefresh = _ref.onTopRefresh,
      onBottomRefresh = _ref.onBottomRefresh,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var rootRef = useRef(null);
  var instance = useRef(null);
  var topContainerRef = useRef(null);
  var bottomContainerRef = useRef(null); // 节点

  useImperativeHandle(ref, function () {
    return {
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInstance: function getInstance() {
        return instance.current;
      }
    };
  }); // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    // 头部刷新,加载第一页
    if (onTopRefresh) {
      instance.current.params.onTopRefresh = onTopRefresh;
    } // 底部刷新,加载下一页


    if (onBottomRefresh) {
      instance.current.params.onBottomRefresh = onBottomRefresh;
    }
  } // 初始化


  useEffect(function () {
    if (typeof onTopRefresh === 'function' || typeof onBottomRefresh === 'function') {
      initInstance();
    }
  }, [onTopRefresh, onBottomRefresh]); // eslint-disable-line

  function initInstance() {
    return _initInstance.apply(this, arguments);
  }

  function _initInstance() {
    _initInstance = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              if (!instance.current) {
                _context.next = 2;
                break;
              }

              return _context.abrupt("return");

            case 2:
              instance.current = new Instance({
                // threshold: 100,
                // end: 200, // 头部下拉的结束位置
                // endRefresh: null, // 滑动到指位置后自动刷新
                // moveTimeout: 0, // 滑动超时, 解决ios手指滑动到原生tabbar上, 不触发onTouchEnd
                container: rootRef.current,
                onScroll: others.onScroll ? others.onScroll : null,
                onTopRefresh: onTopRefresh,
                // 头部刷新,加载第一页
                onBottomRefresh: onBottomRefresh,
                // 底部刷新,加载下一页
                // 构建实体
                topContainer: onTopRefresh ? topContainerRef.current : null,
                bottomContainer: onBottomRefresh ? bottomContainerRef.current : null,
                // 实体交互
                duration: 150,
                onPull: function onPull(e) {
                  var topContainer = e.topContainer;
                  topContainer.style.height = e.touches.currentPosY + 'px';
                  var topIcon = topContainer.querySelector('.body-pull-push-icon');
                  var topCaption = topContainer.querySelector('.body-pull-push-caption');

                  if (!e.isLoading) {
                    if (e.touches.currentPosY >= e.params.threshold) {
                      if (topIcon) topIcon.classList.add('body-pull-push-icon-down');
                      if (topCaption) topCaption.innerHTML = locale('释放立即刷新', 'release');
                    } else {
                      if (topIcon) topIcon.classList.remove('body-pull-push-icon-down');
                      if (topCaption) topCaption.innerHTML = locale('下拉可以刷新', 'pull_down');
                    }
                  }
                },
                onShowTop: function onShowTop(e) {
                  var topContainer = e.topContainer;
                  var topIcon = topContainer.querySelector('.body-pull-push-icon');
                  var topCaption = topContainer.querySelector('.body-pull-push-caption');
                  topContainer.style.height = e.params.threshold + 'px';
                  if (topIcon) topIcon.classList.remove('body-pull-push-icon-down');
                  if (topIcon) topIcon.classList.add('body-pull-push-icon-loading');
                  if (topCaption) topCaption.innerHTML = locale('正在刷新...', 'refreshing');
                },
                onHideTop: function onHideTop(e) {
                  var topContainer = e.topContainer;
                  topContainer.style.height = '0';
                },
                onTopHid: function onTopHid(e) {
                  var topContainer = e.topContainer;
                  var topIcon = topContainer.querySelector('.body-pull-push-icon');
                  if (topIcon) topIcon.classList.remove('body-pull-push-icon-down');
                  if (topIcon) topIcon.classList.remove('body-pull-push-icon-loading');
                }
              });

            case 3:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));
    return _initInstance.apply(this, arguments);
  }

  return /*#__PURE__*/React.createElement("article", _extends({
    ref: rootRef
  }, others, {
    className: "body" + (others.className ? ' ' + others.className : '')
  }), /*#__PURE__*/React.createElement(TopContainer, {
    ref: topContainerRef
  }), children);
});
export default Body;
